BlindedPublicKey

Struct BlindedPublicKey 

pub struct BlindedPublicKey<K: KeyPair> { /* private fields */ }
An ECDH public key that has been blinded, enabling a third party to send a message without knowing the cryptographic identity of the recipient.