Hint

Struct Hint 

pub struct Hint<K: KeyPair, A: Aead + KeyInit, L: ArraySize>
where Self: HintSized<K, A, L>,
{ /* private fields */ }
Message encrypted by a third party, decryptable by an anonymous recipient that doesn’t know whether it is addressed to them or not.