Hints

Struct Hints 

pub struct Hints<H, const S: usize> { /* private fields */ }
Batch of Hints that enforces inner vector size as well as shuffling, and also mitigates potential timing leaks at creation time.

  1. If fewer HintSeed items than S are supplied during creation, decoy HintSeed will fill the remaining slots.
  2. A new temporary K::SecretKey is generated, which is used as a one-off contribution to the group secrets used to encrypt the respective Hint’s messages.
  3. In order to make sure passive attackers don’t know which Hint to brute force, the Hints order should not be deterministic, so decoy and real Hints get shuffled before the result is returned.

In aggregate, this ensures that even if the same HintSeed is used to create multiple Hints instances, they are indistinguishable to passive observers that want to infer communication patterns by repeatedly polling a server or other intermediary.

Implementations

Source

impl<K: KeyPair, A: Aead + KeyInit, L: ArraySize, const S: usize> Hints<Hint<K, A, L>, S>
where Hint<K, A, L>: HintSized<K, A, L> + Hinting<K, L>,

pub fn new( hint_seeds: &[HintSeed<K, L>], context: &[u8], csprng: &mut impl CryptoRng, ) -> Result<Self, Error>
where HintSeed<K, L>: Decoy,

Build shuffled batch of Hint instances from a HintSeed slice, context, and an RNG, resulting in a total of S items.

Note: Although this associated function attempts to account for it, timing leaks MAY happen here. The mitigations’ effectiveness has not yet been independently verified.

pub fn as_slice(&self) -> &[Hint<K, A, L>]

View as slice.

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Deserialize from byte slice.

pub fn to_bytes(self) -> Vec<u8>

Serialize to byte vector.