pub struct BlindedPublicKey<K: KeyPair> { /* private fields */ }Expand description
An ECDH public key that has been blinded, enabling a third party to send a message without knowing the cryptographic identity of the recipient.