pub struct Hint<K: KeyPair, A: Aead + KeyInit, L: ArraySize>where
Self: HintSized<K, A, L>,{ /* private fields */ }Expand description
Message encrypted by a third party, decryptable by an anonymous recipient that doesn’t know whether it is addressed to them or not.