pub struct Hints<H, const S: usize> { /* private fields */ }Expand description
Batch of Hints that enforces inner vector size as well as shuffling, and also mitigates
potential timing leaks at creation time.
- If fewer
HintSeeditems thanSare supplied during creation, decoyHintSeedwill fill the remaining slots. - A new temporary
K::SecretKeyis generated, which is used as a one-off contribution to the group secrets used to encrypt the respectiveHint’s messages. - In order to make sure passive attackers don’t know which
Hintto brute force, theHintsorder should not be deterministic, so decoy and realHints get shuffled before the result is returned.
In aggregate, this ensures that even if the same HintSeed is used to create multiple Hints
instances, they are indistinguishable to passive observers that want to infer communication
patterns by repeatedly polling a server or other intermediary.
Implementations
Sourceimpl<K: KeyPair, A: Aead + KeyInit, L: ArraySize, const S: usize> Hints<Hint<K, A, L>, S>
impl<K: KeyPair, A: Aead + KeyInit, L: ArraySize, const S: usize> Hints<Hint<K, A, L>, S>